Interface: Registry | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: Registry

Please use the module's default export which provides a singleton instance Note: class is exported for typedoc

## # Properties

### # controllers

• `Readonly` controllers: `TypedRegistry`<`DatasetController`<keyof `ChartTypeRegistry`, `Element`<`AnyObject`, `AnyObject`>, `Element`<`AnyObject`, `AnyObject`>, `number` | `BarParsedData` | `CartesianParsedData` | `BubbleParsedData` | `RadialParsedData`>>

#### # Defined in

index.esm.d.ts:1120
(opens new window)

### # elements

• `Readonly` elements: `TypedRegistry`<`Element`<`AnyObject`, `AnyObject`>>

#### # Defined in

index.esm.d.ts:1121
(opens new window)

### # plugins

• `Readonly` plugins: `TypedRegistry`<`Plugin`<keyof `ChartTypeRegistry`, `AnyObject`>>

#### # Defined in

index.esm.d.ts:1122
(opens new window)

### # scales

• `Readonly` scales: `TypedRegistry`<`Scale`<`CoreScaleOptions`>>

#### # Defined in

index.esm.d.ts:1123
(opens new window)

## # Methods

### # add

▸ add(...`args`): `void`

#### # Parameters

Name | Type
--- | ---
`...args` | `ChartComponentLike`[]

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1125
(opens new window)

### # addControllers

▸ addControllers(...`args`): `void`

#### # Parameters

Name | Type
--- | ---
`...args` | `ChartComponentLike`[]

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1128
(opens new window)

### # addElements

▸ addElements(...`args`): `void`

#### # Parameters

Name | Type
--- | ---
`...args` | `ChartComponentLike`[]

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1129
(opens new window)

### # addPlugins

▸ addPlugins(...`args`): `void`

#### # Parameters

Name | Type
--- | ---
`...args` | `ChartComponentLike`[]

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1130
(opens new window)

### # addScales

▸ addScales(...`args`): `void`

#### # Parameters

Name | Type
--- | ---
`...args` | `ChartComponentLike`[]

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1131
(opens new window)

### # getController

▸ getController(`id`): `DatasetController`<keyof `ChartTypeRegistry`, `Element`<`AnyObject`, `AnyObject`>, `Element`<`AnyObject`, `AnyObject`>, `number` | `BarParsedData` | `CartesianParsedData` | `BubbleParsedData` | `RadialParsedData`>

#### # Parameters

Name | Type
--- | ---
`id` | `string`

#### # Returns

`DatasetController`<keyof `ChartTypeRegistry`, `Element`<`AnyObject`, `AnyObject`>, `Element`<`AnyObject`, `AnyObject`>, `number` | `BarParsedData` | `CartesianParsedData` | `BubbleParsedData` | `RadialParsedData`>

#### # Defined in

index.esm.d.ts:1133
(opens new window)

### # getElement

▸ getElement(`id`): `Element`<`AnyObject`, `AnyObject`>

#### # Parameters

Name | Type
--- | ---
`id` | `string`

#### # Returns

`Element`<`AnyObject`, `AnyObject`>

#### # Defined in

index.esm.d.ts:1134
(opens new window)

### # getPlugin

▸ getPlugin(`id`): `Plugin`<keyof `ChartTypeRegistry`, `AnyObject`>

#### # Parameters

Name | Type
--- | ---
`id` | `string`

#### # Returns

`Plugin`<keyof `ChartTypeRegistry`, `AnyObject`>

#### # Defined in

index.esm.d.ts:1135
(opens new window)

### # getScale

▸ getScale(`id`): `Scale`<`CoreScaleOptions`>

#### # Parameters

Name | Type
--- | ---
`id` | `string`

#### # Returns

`Scale`<`CoreScaleOptions`>

#### # Defined in

index.esm.d.ts:1136
(opens new window)

### # remove

▸ remove(...`args`): `void`

#### # Parameters

Name | Type
--- | ---
`...args` | `ChartComponentLike`[]

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1126
(opens new window)